[gnome-packagekit] Spell check strings and comments



commit 51074efc4a9c5939f0be78cd0ddf08042d9c04af
Author: Piotr DrÄg <piotrdrag gmail com>
Date:   Mon Feb 6 18:37:16 2012 +0100

    Spell check strings and comments
    
    Mostly British English to US English changes, but also some typos.

 data/gpk-service-pack.ui              |    2 +-
 data/gpk-signature.ui                 |    2 +-
 data/org.gnome.packagekit.gschema.xml |    4 +-
 help/C/gnome-packagekit.xml           |   19 +++++-----
 man/gpk-application.sgml              |    2 +-
 man/gpk-backend-status.sgml           |    2 +-
 man/gpk-install-provide-file.sgml     |    2 +-
 python/packagekit/gtkwidgets.py       |    2 +-
 src/gpk-application.c                 |   16 ++++----
 src/gpk-common.c                      |   10 +++---
 src/gpk-dbus-service.c                |    4 +-
 src/gpk-dbus-task.c                   |   14 ++++----
 src/gpk-debug.c                       |    6 ++--
 src/gpk-enum.c                        |   62 ++++++++++++++++----------------
 src/gpk-error.c                       |   12 +++---
 src/gpk-install-catalog.c             |    4 +-
 src/gpk-install-local-file.c          |    2 +-
 src/gpk-install-mime-type.c           |    4 +-
 src/gpk-install-package-name.c        |    2 +-
 src/gpk-install-provide-file.c        |    6 ++--
 src/gpk-log.c                         |    6 ++--
 src/gpk-service-pack.c                |    4 +-
 src/gpk-task.c                        |    2 +-
 src/gpk-update-viewer.c               |   12 +++---
 src/org.freedesktop.PackageKit.xml    |    2 +-
 25 files changed, 102 insertions(+), 101 deletions(-)
---
diff --git a/data/gpk-service-pack.ui b/data/gpk-service-pack.ui
index bf5b663..c7ea8ec 100644
--- a/data/gpk-service-pack.ui
+++ b/data/gpk-service-pack.ui
@@ -173,7 +173,7 @@
                             <property name="do_overwrite_confirmation">True</property>
                             <property name="preview_widget_active">False</property>
                             <property name="local_only">False</property>
-                            <property name="title" translatable="yes">Select A Package List File</property>
+                            <property name="title" translatable="yes">Select a Package List File</property>
                           </object>
                           <packing>
                             <property name="left_attach">1</property>
diff --git a/data/gpk-signature.ui b/data/gpk-signature.ui
index d33ba6e..bd10831 100644
--- a/data/gpk-signature.ui
+++ b/data/gpk-signature.ui
@@ -201,7 +201,7 @@
             <child>
               <object class="GtkLabel" id="label2">
                 <property name="visible">True</property>
-                <property name="label" translatable="yes">Do you recognise the user and trust this key?</property>
+                <property name="label" translatable="yes">Do you recognize the user and trust this key?</property>
               </object>
               <packing>
                 <property name="expand">False</property>
diff --git a/data/org.gnome.packagekit.gschema.xml b/data/org.gnome.packagekit.gschema.xml
index 51b32c4..b515661 100644
--- a/data/org.gnome.packagekit.gschema.xml
+++ b/data/org.gnome.packagekit.gschema.xml
@@ -97,11 +97,11 @@
     </key>
     <key name="dbus-default-interaction" type="s">
       <default>'show-confirm-search,show-confirm-deps,show-confirm-install,show-progress,show-finished,show-warning'</default>
-      <description>When displaying UI from a session DBus request, automatically use these options by default.</description>
+      <description>When displaying UI from a session D-Bus request, automatically use these options by default.</description>
     </key>
     <key name="dbus-enforced-interaction" type="s">
       <default>'show-confirm-install'</default>
-      <description>When displaying UI from a session DBus request, force these options to be turned on.</description>
+      <description>When displaying UI from a session D-Bus request, force these options to be turned on.</description>
     </key>
   </schema>
 </schemalist>
diff --git a/help/C/gnome-packagekit.xml b/help/C/gnome-packagekit.xml
index af947fb..66665e2 100644
--- a/help/C/gnome-packagekit.xml
+++ b/help/C/gnome-packagekit.xml
@@ -169,7 +169,7 @@
   <title>Applications</title>
   <para>
     <application>packagekitd</application> is started automatically when it is
-    needed. <command>pkcon</command> offers a versatile commandline interface
+    needed. <command>pkcon</command> offers a versatile command line interface
     to PackageKit.
   </para>
   <para>
@@ -300,12 +300,12 @@
     </para>
     <para>
       To see only installed or only uninstalled software, choose the
-      corresponding menuitem in the <menuchoice><guimenu>Filters</guimenu>
+      corresponding menu item in the <menuchoice><guimenu>Filters</guimenu>
       <guisubmenu>Installed</guisubmenu></menuchoice> menu.
     </para>
     <para>
       To see only software containing applications with a graphical user
-      interface or only applications with a commandline interface, choose a
+      interface or only applications with a command line interface, choose a
       filter from the <menuchoice><guimenu>Filters</guimenu>
       <guisubmenu>Graphical</guisubmenu></menuchoice>
       menu.
@@ -371,13 +371,14 @@
   <title>File Handler Helper</title>
   <para>
     Sometimes you will not have the software on your system to open a particular
-    file. If the file type is not recognised, then applications that can open
+    file. If the file type is not recognized, then applications that can open
     this file type are shown.
   </para>
   <para>
     At this time, only a limited number of results will be shown, as they will
-    need to be rebuilt by the distro to support the extra data needed by PackageKit.
-    This will happen automatically, and soon all suitable applications will be shown.
+    need to be rebuilt by the distribution to support the extra data needed by
+    PackageKit. This will happen automatically, and soon all suitable
+    applications will be shown.
   </para>
 </section>
 
@@ -631,17 +632,17 @@
     <literal>k3b</literal> so that it can burn DVD-RWs.
   </para>
   <para>
-    The <literal>k3b</literal> program has dependancies of <literal>dbus</literal>,
+    The <literal>k3b</literal> program has dependencies of <literal>dbus</literal>,
     <literal>dbus-glib</literal> and <literal>kdebase</literal>.
     Now, if we asked computer A to download <literal>k3b</literal>, it would download
-    <literal>k3b</literal> <emphasis>and</emphasis> <literal>kdebase</literal> but
+    <literal>k3b</literal> <emphasis>and</emphasis> <literal>kdebase</literal>, but
     <emphasis>not</emphasis> <literal>dbus-glib</literal>.
     We need to provide computer A with the information about what packages computer B
     has got installed before we can create the service pack.
   </para>
   <para>
     If we generate a package list on computer B, and the transfer it to
-    computer A on a USB pendrive or CDRW we can download the correct packages.
+    computer A on a USB pendrive or CD-RW we can download the correct packages.
     In this case we would download <literal>k3b</literal> and
     <literal>dbus-glib</literal> and pack it into the new service pack.
   </para>
diff --git a/man/gpk-application.sgml b/man/gpk-application.sgml
index 0507924..1cdffbb 100644
--- a/man/gpk-application.sgml
+++ b/man/gpk-application.sgml
@@ -41,7 +41,7 @@
       This manual page documents briefly the <command>&package;</command> command.
     </para>
     <para>
-      <command>&package;</command> allows you to install a package that provides a filename on
+      <command>&package;</command> allows you to install a package that provides a file name on
       the system.
     </para>
   </refsect1>
diff --git a/man/gpk-backend-status.sgml b/man/gpk-backend-status.sgml
index 87f6359..d1eb6cc 100644
--- a/man/gpk-backend-status.sgml
+++ b/man/gpk-backend-status.sgml
@@ -41,7 +41,7 @@
       This manual page documents briefly the <command>&package;</command> command.
     </para>
     <para>
-      <command>&package;</command> allows you to install a package that provides a filename on
+      <command>&package;</command> allows you to install a package that provides a file name on
       the system.
     </para>
   </refsect1>
diff --git a/man/gpk-install-provide-file.sgml b/man/gpk-install-provide-file.sgml
index 94f30c0..c652489 100644
--- a/man/gpk-install-provide-file.sgml
+++ b/man/gpk-install-provide-file.sgml
@@ -42,7 +42,7 @@
       This manual page documents briefly the <command>&package;</command> command.
     </para>
     <para>
-      <command>&package;</command> allows you to install a package that provides a filename on
+      <command>&package;</command> allows you to install a package that provides a file name on
       the system.
     </para>
   </refsect1>
diff --git a/python/packagekit/gtkwidgets.py b/python/packagekit/gtkwidgets.py
index 9b4cbe6..dae3625 100644
--- a/python/packagekit/gtkwidgets.py
+++ b/python/packagekit/gtkwidgets.py
@@ -1,5 +1,5 @@
 """
-This module provides widgets to use PackageKit in a GTK application.
+This module provides widgets to use PackageKit in a GTK+ application.
 """
 #Copyright (C) 2008 Sebastian Heinlein <sevel glatzor de>
 
diff --git a/src/gpk-application.c b/src/gpk-application.c
index 30e1530..f568f9c 100644
--- a/src/gpk-application.c
+++ b/src/gpk-application.c
@@ -1029,7 +1029,7 @@ gpk_application_get_depends_cb (PkClient *client, GAsyncResult *res, gpointer us
 					   "%i additional packages are required for %s",
 					   array->len), array->len, name);
 
-	/* TRANSLATORS: message: show the array of dependant packages for this package */
+	/* TRANSLATORS: message: show the array of dependent packages for this package */
 	message = g_strdup_printf (ngettext ("Packages listed below are required for %s to function correctly.",
 					     "Packages listed below are required for %s to function correctly.",
 					     array->len), name);
@@ -1598,7 +1598,7 @@ gpk_application_perform_search_name_details_file (gpointer user_data)
 		/* TODO - make the dialog turn red... */
 		window = GTK_WINDOW (gtk_builder_get_object (builder, "window_manager"));
 		gpk_error_dialog_modal (window,
-					/* TRANSLATORS: title: invlid text in the search bar */
+					/* TRANSLATORS: title: invalid text in the search bar */
 					_("Invalid search text"),
 					/* TRANSLATORS: message: tell the user that's not allowed */
 					_("The search text contains invalid characters"), NULL);
@@ -1641,7 +1641,7 @@ gpk_application_perform_search_name_details_file (gpointer user_data)
 	if (!ret) {
 		window = GTK_WINDOW (gtk_builder_get_object (builder, "window_manager"));
 		gpk_error_dialog_modal (window,
-					/* TRANSLATORS: title: we failed to execute the mthod */
+					/* TRANSLATORS: title: we failed to execute the method */
 					_("The search could not be completed"),
 					/* TRANSLATORS: low level failure, details to follow */
 					_("Running the transaction failed"), error->message);
@@ -3547,7 +3547,7 @@ pk_backend_status_get_properties_cb (GObject *object, GAsyncResult *res, gpointe
 		if (pk_bitfield_contain (roles, PK_ROLE_ENUM_SEARCH_DETAILS)) {
 			gpk_application_menu_search_by_description (NULL, NULL);
 		} else {
-			g_warning ("cannont use mode %i as not capable, using name", search_type);
+			g_warning ("cannot use mode %i as not capable, using name", search_type);
 			gpk_application_menu_search_by_name (NULL, NULL);
 		}
 
@@ -3558,13 +3558,13 @@ pk_backend_status_get_properties_cb (GObject *object, GAsyncResult *res, gpointe
 		if (pk_bitfield_contain (roles, PK_ROLE_ENUM_SEARCH_FILE)) {
 			gpk_application_menu_search_by_file (NULL, NULL);
 		} else {
-			g_warning ("cannont use mode %i as not capable, using name", search_type);
+			g_warning ("cannot use mode %i as not capable, using name", search_type);
 			gpk_application_menu_search_by_name (NULL, NULL);
 		}
 
-	/* mode not recognised */
+	/* mode not recognized */
 	} else {
-		g_warning ("cannot recognise mode %i, using name", search_type);
+		g_warning ("cannot recognize mode %i, using name", search_type);
 		gpk_application_menu_search_by_name (NULL, NULL);
 	}
 out:
@@ -3712,7 +3712,7 @@ gpk_application_startup_cb (GtkApplication *application, gpointer user_data)
 	g_signal_connect (control, "notify::network-state",
 			  G_CALLBACK (gpk_application_notify_network_state_cb), NULL);
 
-	/* get localised data from sqlite database */
+	/* get localized data from sqlite database */
 	desktop = pk_desktop_new ();
 	ret = pk_desktop_open_database (desktop, NULL);
 	if (!ret)
diff --git a/src/gpk-common.c b/src/gpk-common.c
index 8b6ddc8..81add1b 100644
--- a/src/gpk-common.c
+++ b/src/gpk-common.c
@@ -43,7 +43,7 @@
 #define GNOME_SESSION_MANAGER_PATH		"/org/gnome/SessionManager"
 #define GNOME_SESSION_MANAGER_INTERFACE		"org.gnome.SessionManager"
 
-/* if the dialog is going to cover more than this much of the screen, then maximise it at startup */
+/* if the dialog is going to cover more than this much of the screen, then maximize it at startup */
 #define GPK_SMALL_FORM_FACTOR_SCREEN_PERCENT	75 /* % */
 
 /* static, so local to process */
@@ -426,7 +426,7 @@ gpk_check_privileged_user (const gchar *application_name, gboolean show_ui)
 			/* TRANSLATORS: these tools cannot run as root (unknown name) */
 			title = g_strdup (_("This application is running as a privileged user"));
 		else
-			/* TRANSLATORS: cannot run as root user, and we display the applicaiton name */
+			/* TRANSLATORS: cannot run as root user, and we display the application name */
 			title = g_strdup_printf (_("%s is running as a privileged user"), application_name);
 		message = g_strjoin ("\n",
 				     /* TRANSLATORS: tell the user off */
@@ -493,7 +493,7 @@ gpk_set_animated_icon_from_status (GpkAnimatedIcon *icon, PkStatusEnum status, G
  * gpk_time_to_imprecise_string:
  * @time_secs: The time value to convert in seconds
  *
- * Returns a localised timestring
+ * Returns a localized timestring
  *
  * Return value: The time string, e.g. "2 hours"
  **/
@@ -543,7 +543,7 @@ out:
  * gpk_time_to_localised_string:
  * @time_secs: The time value to convert in seconds
  *
- * Returns a localised timestring
+ * Returns a localized timestring
  *
  * Return value: The time string, e.g. "2 hours 3 minutes"
  **/
@@ -779,7 +779,7 @@ gpk_package_entry_completion_new (void)
 /**
  * gpk_ignore_session_error:
  *
- * Returns true if the error is a remote exception where we cancelled
+ * Returns true if the error is a remote exception where we canceled
  **/
 gboolean
 gpk_ignore_session_error (GError *error)
diff --git a/src/gpk-dbus-task.c b/src/gpk-dbus-task.c
index 26f876d..2f3a6ed 100644
--- a/src/gpk-dbus-task.c
+++ b/src/gpk-dbus-task.c
@@ -290,7 +290,7 @@ gpk_dbus_task_error_msg (GpkDbusTask *dtask, const gchar *title, GError *error)
 {
 	GtkWindow *window;
 	/* TRANSLATORS: default fallback error -- this should never happen */
-	const gchar *message = _("Unknown error. Please refer to the detailed report and report in your distribution bugtracker.");
+	const gchar *message = _("Unknown error. Please refer to the detailed report and report in your distribution bug tracker.");
 	const gchar *details = NULL;
 
 	if (!dtask->priv->show_warning)
@@ -403,7 +403,7 @@ gpk_dbus_task_get_code_from_gerror (const GError *error)
 		goto out;
 	}
 
-	/* not recognised */
+	/* not recognized */
 	if (error->domain != PK_CLIENT_ERROR) {
 		g_warning ("Not a PkClientError error code");
 		goto out;
@@ -2256,7 +2256,7 @@ gpk_dbus_task_install_fontconfig_resources (GpkDbusTask *dtask, gchar **fonts, G
 	for (i=0; i<len; i++) {
 		/* correct prefix */
 		if (!g_str_has_prefix (fonts[i], ":lang=")) {
-			error_dbus = g_error_new (GPK_DBUS_ERROR, GPK_DBUS_ERROR_INTERNAL_ERROR, "not recognised prefix: '%s'", fonts[i]);
+			error_dbus = g_error_new (GPK_DBUS_ERROR, GPK_DBUS_ERROR_INTERNAL_ERROR, "not recognized prefix: '%s'", fonts[i]);
 			gpk_dbus_task_dbus_return_error (dtask, error_dbus);
 			g_error_free (error_dbus);
 			goto out;
@@ -2690,7 +2690,7 @@ gpk_dbus_task_catalog_lookup_cb (GObject *object, GAsyncResult *res, GpkDbusTask
 
 	/* did we click no or exit the window? */
 	if (button != GTK_RESPONSE_OK) {
-		error_dbus = g_error_new (GPK_DBUS_ERROR, GPK_DBUS_ERROR_CANCELLED, "Action was cancelled");
+		error_dbus = g_error_new (GPK_DBUS_ERROR, GPK_DBUS_ERROR_CANCELLED, "Action was canceled");
 		gpk_dbus_task_dbus_return_error (dtask, error_dbus);
 		g_error_free (error_dbus);
 		goto out;
@@ -3003,7 +3003,7 @@ gpk_dbus_task_remove_package_by_file_search_file_cb (PkClient *client, GAsyncRes
 	if (array->len == 0) {
 		if (dtask->priv->show_warning) {
 			gpk_modal_dialog_setup (dtask->priv->dialog, GPK_MODAL_DIALOG_PAGE_WARNING, 0);
-			/* TRANSLATORS: failed to fild the package for thefile */
+			/* TRANSLATORS: failed to find the package for the file */
 			gpk_modal_dialog_set_title (dtask->priv->dialog, _("Failed to find package for this file"));
 			/* TRANSLATORS: nothing found */
 			gpk_modal_dialog_set_message (dtask->priv->dialog, _("The file could not be found in any packages"));
@@ -3310,7 +3310,7 @@ gpk_dbus_task_set_exec (GpkDbusTask *dtask, const gchar *exec)
 		dtask->priv->parent_icon_name = gpk_desktop_guess_icon_name (dtask->priv->desktop, package);
 		/* fallback to package name */
 		if (dtask->priv->parent_title == NULL) {
-			g_debug ("did not get localised description for %s", package);
+			g_debug ("did not get localized description for %s", package);
 			dtask->priv->parent_title = g_strdup (package);
 		}
 	}
@@ -3372,7 +3372,7 @@ gpk_dbus_task_init (GpkDbusTask *dtask)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   GPK_DATA G_DIR_SEPARATOR_S "icons");
 
-	/* only initialise if the application didn't do it before */
+	/* only initialize if the application didn't do it before */
 	if (!notify_is_initted ())
 		notify_init (_("Software Install"));
 
diff --git a/src/gpk-debug.c b/src/gpk-debug.c
index 1bd3223..82217d8 100644
--- a/src/gpk-debug.c
+++ b/src/gpk-debug.c
@@ -175,12 +175,12 @@ gpk_debug_post_parse_hook (GOptionContext *context, GOptionGroup *group, gpointe
 /**
  * gpk_debug_get_option_group:
  *
- * Returns a #GOptionGroup for the commandline arguments recognized
+ * Returns a #GOptionGroup for the command line arguments recognized
  * by debugging. You should add this group to your #GOptionContext
  * with g_option_context_add_group(), if you are using
- * g_option_context_parse() to parse your commandline arguments.
+ * g_option_context_parse() to parse your command line arguments.
  *
- * Returns: a #GOptionGroup for the commandline arguments
+ * Returns: a #GOptionGroup for the command line arguments
  */
 GOptionGroup *
 gpk_debug_get_option_group (void)
diff --git a/src/gpk-error.c b/src/gpk-error.c
index af4f909..9f232bc 100644
--- a/src/gpk-error.c
+++ b/src/gpk-error.c
@@ -52,8 +52,8 @@ gpk_error_dialog_expanded_cb (GObject *object, GParamSpec *param_spec, GtkBuilde
 /**
  * gpk_error_dialog_modal_with_time:
  * @window: the parent dialog
- * @title: the localised text to put in bold as a title
- * @message: the localised text to put as a message
+ * @title: the localized text to put in bold as a title
+ * @message: the localized text to put as a message
  * @details: the geeky text to in the expander, or %NULL if nothing
  *
  * Shows a modal error, and blocks until the user clicks close
@@ -144,8 +144,8 @@ out_build:
 /**
  * gpk_error_dialog_modal:
  * @window: the parent dialog
- * @title: the localised text to put in bold as a title
- * @message: the localised text to put as a message
+ * @title: the localized text to put in bold as a title
+ * @message: the localized text to put as a message
  * @details: the geeky text to in the expander, or %NULL if nothing
  *
  * Shows a modal error, and blocks until the user clicks close
@@ -158,8 +158,8 @@ gpk_error_dialog_modal (GtkWindow *window, const gchar *title, const gchar *mess
 
 /**
  * gpk_error_dialog:
- * @title: the localised text to put in bold as a title
- * @message: the localised text to put as a message
+ * @title: the localized text to put in bold as a title
+ * @message: the localized text to put as a message
  * @details: the geeky text to in the expander, or %NULL if nothing
  *
  * Shows a modal error, and blocks until the user clicks close
diff --git a/src/gpk-install-catalog.c b/src/gpk-install-catalog.c
index 22ccb4d..878c098 100644
--- a/src/gpk-install-catalog.c
+++ b/src/gpk-install-catalog.c
@@ -81,7 +81,7 @@ main (int argc, char *argv[])
 
 	if (files == NULL) {
 		gpk_error_dialog (_("Failed to install catalog"),
-				  /* TRANSLATORS: no filename was supplied */
+				  /* TRANSLATORS: no file name was supplied */
 				  _("You need to specify a file name to install"), NULL);
 		goto out;
 	}
@@ -114,7 +114,7 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
diff --git a/src/gpk-install-local-file.c b/src/gpk-install-local-file.c
index 95d1c51..3af4a2d 100644
--- a/src/gpk-install-local-file.c
+++ b/src/gpk-install-local-file.c
@@ -114,7 +114,7 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
diff --git a/src/gpk-install-mime-type.c b/src/gpk-install-mime-type.c
index 8ebe44a..0124a15 100644
--- a/src/gpk-install-mime-type.c
+++ b/src/gpk-install-mime-type.c
@@ -82,7 +82,7 @@ main (int argc, char *argv[])
 		/* TRANSLATORS: could not install program supporting this type */
 		gpk_error_dialog (_("Failed to install a program to handle this file type"),
 				  /* TRANSLATORS: no type given */
-				  _("You need to specify a mime-type to install"), NULL);
+				  _("You need to specify a mime type to install"), NULL);
 		goto out;
 	}
 
@@ -114,7 +114,7 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
diff --git a/src/gpk-install-package-name.c b/src/gpk-install-package-name.c
index 947c893..61a594f 100644
--- a/src/gpk-install-package-name.c
+++ b/src/gpk-install-package-name.c
@@ -113,7 +113,7 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
diff --git a/src/gpk-install-provide-file.c b/src/gpk-install-provide-file.c
index 5ae74d8..86b4e0e 100644
--- a/src/gpk-install-provide-file.c
+++ b/src/gpk-install-provide-file.c
@@ -81,8 +81,8 @@ main (int argc, char *argv[])
 	if (files == NULL) {
 		/* TRANSLATORS: nothing done */
 		gpk_error_dialog (_("Failed to install a package to provide a file"),
-				  /* TRANSLATORS: nothig was specified */
-				  _("You need to specify a filename to install"), NULL);
+				  /* TRANSLATORS: nothing was specified */
+				  _("You need to specify a file name to install"), NULL);
 		goto out;
 	}
 
@@ -114,7 +114,7 @@ main (int argc, char *argv[])
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
-		/* TRANSLATORS: This is when the specified DBus method did not execute successfully */
+		/* TRANSLATORS: This is when the specified D-Bus method did not execute successfully */
 		gpk_error_dialog (_("The action could not be completed"),
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
diff --git a/src/gpk-service-pack.c b/src/gpk-service-pack.c
index 698b76d..63a1109 100644
--- a/src/gpk-service-pack.c
+++ b/src/gpk-service-pack.c
@@ -569,7 +569,7 @@ gpk_pack_button_create_cb (GtkWidget *widget2, gpointer data)
 
 		/* tell the user what we are doing */
 		progress_bar = GTK_PROGRESS_BAR (gtk_builder_get_object (builder, "progressbar_percentage"));
-		/* TRANSLATORS: progressbar text */
+		/* TRANSLATORS: progress bar text */
 		gtk_progress_bar_set_text (progress_bar, _("Refreshing system package array"));
 
 		/* refresh package array */
@@ -802,7 +802,7 @@ gpm_pack_commandline_cb (GApplication *application,
 		  _("Add the package name to the text entry box"), NULL },
 		{ "with-array", 'p', 0, G_OPTION_ARG_STRING, &with_array,
 		  /* TRANSLATORS: this is the destination computer package array */
-		  _("Set the remote package array filename"), NULL },
+		  _("Set the remote package array file name"), NULL },
 		{ "output", 'p', 0, G_OPTION_ARG_STRING, &output,
 		  /* TRANSLATORS: this is the file output directory */
 		  _("Set the default output directory"), NULL },
diff --git a/src/gpk-task.c b/src/gpk-task.c
index 95cfe4d..4188ac1 100644
--- a/src/gpk-task.c
+++ b/src/gpk-task.c
@@ -353,7 +353,7 @@ gpk_task_media_change_question (PkTask *task, guint request, PkResults *results)
 
 	priv->current_window = GTK_WINDOW (gtk_message_dialog_new (priv->parent_window,
 								   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-								   /* TRANSLATORS: this is the window title when a new cd or dvd is required */
+								   /* TRANSLATORS: this is the window title when a new CD or DVD is required */
 								   GTK_MESSAGE_INFO, GTK_BUTTONS_CANCEL, _("A media change is required")));
 	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG(priv->current_window), "%s", message);
 
diff --git a/src/gpk-update-viewer.c b/src/gpk-update-viewer.c
index 549d4f0..c401e4e 100644
--- a/src/gpk-update-viewer.c
+++ b/src/gpk-update-viewer.c
@@ -223,15 +223,15 @@ gpk_update_viewer_check_restart (void)
 		button = _("Restart Computer");
 
 	} else if (restart_update == PK_RESTART_ENUM_SESSION) {
-		/* TRANSLATORS: the message text for the logout */
+		/* TRANSLATORS: the message text for the log out */
 		message = _("Some of the updates that were installed require you to log out and back in before the changes will be applied.");
-		/* TRANSLATORS: the button text for the logout */
+		/* TRANSLATORS: the button text for the log out */
 		button = _("Log Out");
 
 	} else if (restart_update == PK_RESTART_ENUM_SECURITY_SESSION) {
-		/* TRANSLATORS: the message text for the logout */
+		/* TRANSLATORS: the message text for the log out */
 		message = _("Some of the updates that were installed require you to log out and back in to remain secure.");
-		/* TRANSLATORS: the button text for the logout */
+		/* TRANSLATORS: the button text for the log out */
 		button = _("Log Out");
 
 	} else {
@@ -1441,7 +1441,7 @@ gpk_update_viewer_reconsider_info (void)
 		gpk_update_viewer_modal_error_with_timeout (
 				/* TRANSLATORS: title: nothing to do */
 				_("No updates are available"),
-				/* TRANSLATORS: no network connnection, according to PackageKit */
+				/* TRANSLATORS: no network connection, according to PackageKit */
 				_("No network connection was detected."));
 		goto out;
 	}
@@ -2028,7 +2028,7 @@ gpk_update_viewer_populate_details (PkUpdateDetail *item)
 	/* state */
 	if (state == PK_UPDATE_STATE_ENUM_UNSTABLE) {
 		/* TRANSLATORS: this is the stability status of the update */
-		gtk_text_buffer_insert_with_tags_by_name (text_buffer, &iter, _("The classifaction of this update is unstable which means it is not designed for production use."), -1, "para", NULL);
+		gtk_text_buffer_insert_with_tags_by_name (text_buffer, &iter, _("The classification of this update is unstable which means it is not designed for production use."), -1, "para", NULL);
 		gtk_text_buffer_insert (text_buffer, &iter, "\n", -1);
 	} else if (state == PK_UPDATE_STATE_ENUM_TESTING) {
 		/* TRANSLATORS: this is the stability status of the update */
diff --git a/src/org.freedesktop.PackageKit.xml b/src/org.freedesktop.PackageKit.xml
index efecab8..72ad53c 100644
--- a/src/org.freedesktop.PackageKit.xml
+++ b/src/org.freedesktop.PackageKit.xml
@@ -225,7 +225,7 @@
         <doc:doc>
           <doc:summary>
             <doc:para>
-              An array of catalog filenames.
+              An array of catalog file names.
             </doc:para>
           </doc:summary>
         </doc:doc>



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gpk-dbus-service.c b/src/gpk-dbus-service.c
index 684084c..a0fa46d 100644
--- a/src/gpk-dbus-service.c
+++ b/src/gpk-dbus-service.c
@@ -69,7 +69,7 @@ gpk_dbus_service_object_register (DBusGConnection *connection, GObject *object)
 				 G_TYPE_UINT, &request_name_result,
 				 G_TYPE_INVALID);
 	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("RequestName failed: %s", error->message);
 		g_error_free (error);
 		return FALSE;
@@ -155,7 +155,7 @@ main (int argc, char *argv[])
 	/* TRANSLATORS: program name, a session wide daemon to watch for updates and changing system state */
 	g_set_application_name (_("Software Install"));
 	context = g_option_context_new (NULL);
-	g_option_context_set_summary (context, _("Session DBus service for PackageKit"));
+	g_option_context_set_summary (context, _("Session D-Bus service for PackageKit"));
 	g_option_context_add_main_entries (context, options, NULL);
 	g_option_context_add_group (context, gpk_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
@@ -69,7 +69,7 @@ gpk_dbus_service_object_register (DBusGConnection *connection, GObject *object)
 				 G_TYPE_INVALID);
 	if (!ret) {
-		/* abort as the DBUS method failed */
+		/* abort as the D-Bus method failed */
 		g_warning ("RequestName failed: %s", error->message);
 		g_error_free (error);
diff --git a/src/gpk-enum.c b/src/gpk-enum.c
index 663ba4c..afb5b58 100644
--- a/src/gpk-enum.c
+++ b/src/gpk-enum.c
@@ -395,7 +395,7 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
 		text = _("Failed to initialize");
 		break;
 	case PK_ERROR_ENUM_FAILED_FINALISE:
-		text = _("Failed to finalise");
+		text = _("Failed to finalize");
 		break;
 	case PK_ERROR_ENUM_CANNOT_GET_LOCK:
 		text = _("Cannot get lock");
@@ -536,11 +536,11 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 		break;
 	case PK_ERROR_ENUM_NOT_SUPPORTED:
 		text = _("The action is not supported by this backend.\n"
-			 "Please report a bug in your distribution bugtracker as this should not have happened.");
+			 "Please report a bug in your distribution bug tracker as this should not have happened.");
 		break;
 	case PK_ERROR_ENUM_INTERNAL_ERROR:
 		text = _("A problem that we were not expecting has occurred.\n"
-			 "Please report this bug in your distribution bugtracker with the error description.");
+			 "Please report this bug in your distribution bug tracker with the error description.");
 		break;
 	case PK_ERROR_ENUM_GPG_FAILURE:
 		text = _("A security trust relationship could not be made with software source.\n"
@@ -751,7 +751,7 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 		text = _("The list of software sources could not be downloaded.");
 		break;
 	case PK_ERROR_ENUM_CANCELLED_PRIORITY:
-		text = _("The transaction has been cancelled and will be retried when the system is idle.");
+		text = _("The transaction has been canceled and will be retried when the system is idle.");
 		break;
 	default:
 		g_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
@@ -787,7 +787,7 @@ gpk_restart_enum_to_localised_text_future (PkRestartEnum restart)
 		text = _("A restart will be required due to a security update.");
 		break;
 	default:
-		g_warning ("restart unrecognised: %i", restart);
+		g_warning ("restart unrecognized: %i", restart);
 	}
 	return text;
 }
@@ -819,7 +819,7 @@ gpk_restart_enum_to_localised_text (PkRestartEnum restart)
 		text = _("A restart is required to remain secure.");
 		break;
 	default:
-		g_warning ("restart unrecognised: %i", restart);
+		g_warning ("restart unrecognized: %i", restart);
 	}
 	return text;
 }
@@ -845,7 +845,7 @@ gpk_update_state_enum_to_localised_text (PkUpdateStateEnum state)
 		text = _("Testing");
 		break;
 	default:
-		g_warning ("state unrecognised: %i", state);
+		g_warning ("state unrecognized: %i", state);
 	}
 	return text;
 }
@@ -907,7 +907,7 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 		text = _("Other updates have been held back");
 		break;
 	default:
-		g_warning ("message unrecognised: %i", message);
+		g_warning ("message unrecognized: %i", message);
 	}
 	return text;
 }
@@ -1001,8 +1001,8 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		text = _("Finished");
 		break;
 	case PK_STATUS_ENUM_CANCEL:
-		/* TRANSLATORS: transaction state, in the process of cancelling */
-		text = _("Cancelling");
+		/* TRANSLATORS: transaction state, in the process of canceling */
+		text = _("Canceling");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_REPOSITORY:
 		/* TRANSLATORS: transaction state, downloading metadata */
@@ -1069,7 +1069,7 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		text = _("Copying files");
 		break;
 	default:
-		g_warning ("status unrecognised: %s", pk_status_enum_to_string (status));
+		g_warning ("status unrecognized: %s", pk_status_enum_to_string (status));
 	}
 	return text;
 }
@@ -1111,7 +1111,7 @@ gpk_update_enum_to_localised_text (PkInfoEnum info, guint number)
 		text = g_strdup_printf (ngettext ("%i blocked update", "%i blocked updates", number), number);
 		break;
 	default:
-		g_warning ("update info unrecognised: %s", pk_info_enum_to_string (info));
+		g_warning ("update info unrecognized: %s", pk_info_enum_to_string (info));
 	}
 	return text;
 }
@@ -1171,7 +1171,7 @@ gpk_info_enum_to_localised_text (PkInfoEnum info)
 		text = _("Untrusted");
 		break;
 	default:
-		g_warning ("info unrecognised: %s", pk_info_enum_to_string (info));
+		g_warning ("info unrecognized: %s", pk_info_enum_to_string (info));
 	}
 	return text;
 }
@@ -1221,7 +1221,7 @@ gpk_info_enum_to_localised_present (PkInfoEnum info)
 		text = _("Decompressing");
 		break;
 	default:
-		g_warning ("info unrecognised: %s", pk_info_enum_to_string (info));
+		g_warning ("info unrecognized: %s", pk_info_enum_to_string (info));
 	}
 	return text;
 }
@@ -1271,7 +1271,7 @@ gpk_info_enum_to_localised_past (PkInfoEnum info)
 		text = _("Decompressed");
 		break;
 	default:
-		g_warning ("info unrecognised: %s", pk_info_enum_to_string (info));
+		g_warning ("info unrecognized: %s", pk_info_enum_to_string (info));
 	}
 	return text;
 }
@@ -1429,15 +1429,15 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		text = _("Upgrading system");
 		break;
 	case PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM:
-		/* TRANSLATORS: The role of the transaction, in past tense */
+		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Simulating the system repair");
 		break;
 	case PK_ROLE_ENUM_REPAIR_SYSTEM:
-		/* TRANSLATORS: The role of the transaction, in past tense */
+		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Repairing the system");
 		break;
 	default:
-		g_warning ("role unrecognised: %s", pk_role_enum_to_string (role));
+		g_warning ("role unrecognized: %s", pk_role_enum_to_string (role));
 	}
 	return text;
 }
@@ -1605,7 +1605,7 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		text = _("Repaired the system");
 		break;
 	default:
-		g_warning ("role unrecognised: %s", pk_role_enum_to_string (role));
+		g_warning ("role unrecognized: %s", pk_role_enum_to_string (role));
 	}
 	return text;
 }
@@ -1672,7 +1672,7 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
 		break;
 	case PK_GROUP_ENUM_DESKTOP_XFCE:
 		/* TRANSLATORS: The group type */
-		text = _("XFCE desktop");
+		text = _("Xfce desktop");
 		break;
 	case PK_GROUP_ENUM_DESKTOP_OTHER:
 		/* TRANSLATORS: The group type */
@@ -1759,7 +1759,7 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
 		text = _("Unknown group");
 		break;
 	default:
-		g_warning ("group unrecognised: %i", group);
+		g_warning ("group unrecognized: %i", group);
 	}
 	return text;
 }
@@ -1889,9 +1889,9 @@ gpk_enum_test (gpointer data)
 		return;
 
 	/************************************************************
-	 ****************     localised enums          **************
+	 ****************     localized enums          **************
 	 ************************************************************/
-	egg_test_title (test, "check we convert all the localised past role enums");
+	egg_test_title (test, "check we convert all the localized past role enums");
 	for (i=0; i<PK_ROLE_ENUM_LAST; i++) {
 		string = gpk_role_enum_to_localised_past (i);
 		if (string == NULL) {
@@ -1902,7 +1902,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised present role enums");
+	egg_test_title (test, "check we convert all the localized present role enums");
 	for (i=0; i<PK_ROLE_ENUM_LAST; i++) {
 		string = gpk_role_enum_to_localised_present (i);
 		if (string == NULL) {
@@ -1946,7 +1946,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised status enums");
+	egg_test_title (test, "check we convert all the localized status enums");
 	for (i=0; i<PK_STATUS_ENUM_LAST; i++) {
 		string = gpk_status_enum_to_localised_text (i);
 		if (string == NULL) {
@@ -1979,7 +1979,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised error enums");
+	egg_test_title (test, "check we convert all the localized error enums");
 	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
 		string = gpk_error_enum_to_localised_text (i);
 		if (string == NULL) {
@@ -1990,7 +1990,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised error messages");
+	egg_test_title (test, "check we convert all the localized error messages");
 	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
 		string = gpk_error_enum_to_localised_message (i);
 		if (string == NULL) {
@@ -2001,7 +2001,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised restart enums");
+	egg_test_title (test, "check we convert all the localized restart enums");
 	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
 		string = gpk_restart_enum_to_localised_text (i);
 		if (string == NULL) {
@@ -2023,7 +2023,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised message enums");
+	egg_test_title (test, "check we convert all the localized message enums");
 	for (i=PK_MESSAGE_ENUM_UNKNOWN+1; i<PK_MESSAGE_ENUM_LAST; i++) {
 		string = gpk_message_enum_to_localised_text (i);
 		if (string == NULL) {
@@ -2034,7 +2034,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised restart future enums");
+	egg_test_title (test, "check we convert all the localized restart future enums");
 	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
 		string = gpk_restart_enum_to_localised_text_future (i);
 		if (string == NULL) {
@@ -2045,7 +2045,7 @@ gpk_enum_test (gpointer data)
 	egg_test_success (test, NULL);
 
 	/************************************************************/
-	egg_test_title (test, "check we convert all the localised group enums");
+	egg_test_title (test, "check we convert all the localized group enums");
 	for (i=0; i<PK_GROUP_ENUM_LAST; i++) {
 		string = gpk_group_enum_to_localised_text (i);
 		if (string == NULL) {
diff --git a/src/gpk-log.c b/src/gpk-log.c
index b5929c0..d5db6c7 100644
--- a/src/gpk-log.c
+++ b/src/gpk-log.c
@@ -324,8 +324,8 @@ pk_treeview_add_general_columns (GtkTreeView *treeview)
 	gtk_tree_view_append_column (treeview, column);
 	gtk_tree_view_column_set_expand (column, TRUE);
 
-	/* TRANSLATORS: column for the username, e.g. Richard Hughes */
-	column = gtk_tree_view_column_new_with_attributes (_("Username"), renderer,
+	/* TRANSLATORS: column for the user name, e.g. Richard Hughes */
+	column = gtk_tree_view_column_new_with_attributes (_("User name"), renderer,
 							   "markup", GPK_LOG_COLUMN_USER, NULL);
 	gtk_tree_view_append_column (treeview, column);
 	gtk_tree_view_column_set_expand (column, FALSE);
@@ -506,7 +506,7 @@ gpk_log_add_item (PkTransactionPast *item)
 		/* TRANSLATORS: short name for the command not found plugin */
 		tool = _("Bash - Command Not Found");
 	else if (g_strcmp0 (cmdline, "/usr/libexec/gnome-settings-daemon") == 0)
-		/* TRANSLATORS: user friendly name for gnome-settings-dameon */
+		/* TRANSLATORS: user friendly name for gnome-settings-daemon */
 		tool = _("GNOME Session");
 	else
 		tool = cmdline;